@@ -142,7 +142,9 @@ macro_rules! impl_mono_inc {
 impl Interval {
     /// Returns the inverse cosine of `self`.
     ///
-    /// Tightness: tightest
+    /// | Domain      | Range      |
+    /// | ----------- | ---------- |
+    /// | $\[-1, 1\]$ | $\[0, π\]$ |
     pub fn acos(self) -> Self {
         self.acos_impl().0
     }
@@ -166,7 +168,9 @@ impl Interval {
 
     /// Returns the inverse hyperbolic cosine of `self`.
     ///
-    /// Tightness: tightest
+    /// | Domain    | Range     |
+    /// | --------- | --------- |
+    /// | $\[1, ∞)$ | $\[0, ∞)$ |
     pub fn acosh(self) -> Self {
         self.acosh_impl().0
     }
@@ -190,7 +194,9 @@ impl Interval {
 
     /// Returns the inverse sine of `self`.
     ///
-    /// Tightness: tightest
+    /// | Domain      | Range           |
+    /// | ----------- | --------------- |
+    /// | $\[-1, 1\]$ | $\[-π/2, π/2\]$ |
     pub fn asin(self) -> Self {
         self.asin_impl().0
     }
@@ -215,7 +221,9 @@ impl Interval {
     impl_mono_inc!(
         /// Returns the inverse hyperbolic sine of `self`.
         ///
-        /// Tightness: tightest
+        /// | Domain | Range |
+        /// | ------ | ----- |
+        /// | $\R$   | $\R$  |
         asinh,
         asinh_rd,
         asinh_ru
@@ -223,7 +231,9 @@ impl Interval {
     impl_mono_inc!(
         /// Returns the inverse tangent of `self`.
         ///
-        /// Tightness: tightest
+        /// | Domain | Range         |
+        /// | ------ | ------------- |
+        /// | $\R$   | $(-π/2, π/2)$ |
         atan,
         atan_rd,
         atan_ru
@@ -232,7 +242,9 @@ impl Interval {
     /// Returns the angle of the point $(\rhs, \self)$ measured counterclockwise from the positive
     /// $x$-axis in the Euclidean plane.
     ///
-    /// Tightness: tightest
+    /// | Domain                | Range      |
+    /// | --------------------- | ---------- |
+    /// | $\R^2 ∖ \set{(0, 0)}$ | $(-π, π\]$ |
     pub fn atan2(self, rhs: Self) -> Self {
         self.atan2_impl(rhs).0
     }
@@ -350,7 +362,9 @@ impl Interval {
 
     /// Returns the inverse hyperbolic tangent of `self`.
     ///
-    /// Tightness: tightest
+    /// | Domain    | Range |
+    /// | --------- | ----- |
+    /// | $(-1, 1)$ | $\R$  |
     pub fn atanh(self) -> Self {
         self.atanh_impl().0
     }
@@ -380,7 +394,9 @@ impl Interval {
 
     /// Returns the cosine of `self`.
     ///
-    /// Tightness: tightest
+    /// | Domain | Range       |
+    /// | ------ | ----------- |
+    /// | $\R$   | $\[-1, 1\]$ |
     pub fn cos(self) -> Self {
         if self.is_empty() {
             return self;
@@ -424,7 +440,9 @@ impl Interval {
 
     /// Returns the hyperbolic cosine of `self`.
     ///
-    /// Tightness: tightest
+    /// | Domain | Range     |
+    /// | ------ | --------- |
+    /// | $\R$   | $\[1, ∞)$ |
     pub fn cosh(self) -> Self {
         if self.is_empty() {
             return self;
@@ -444,7 +462,9 @@ impl Interval {
     impl_mono_inc!(
         /// Returns `self` raised to the power of $\e$.
         ///
-        /// Tightness: tightest
+        /// | Domain | Range    |
+        /// | ------ | -------- |
+        /// | $\R$   | $(0, ∞)$ |
         exp,
         exp_rd,
         exp_ru
@@ -452,7 +472,9 @@ impl Interval {
     impl_mono_inc!(
         /// Returns `self` raised to the power of 10.
         ///
-        /// Tightness: tightest
+        /// | Domain | Range    |
+        /// | ------ | -------- |
+        /// | $\R$   | $(0, ∞)$ |
         exp10,
         exp10_rd,
         exp10_ru
@@ -460,7 +482,9 @@ impl Interval {
     impl_mono_inc!(
         /// Returns `self` raised to the power of 2.
         ///
-        /// Tightness: tightest
+        /// | Domain | Range    |
+        /// | ------ | -------- |
+        /// | $\R$   | $(0, ∞)$ |
         exp2,
         exp2_rd,
         exp2_ru
@@ -469,7 +493,9 @@ impl Interval {
     impl_log!(
         /// Returns the natural logarithm of `self`.
         ///
-        /// Tightness: tightest
+        /// | Domain   | Range |
+        /// | -------- | ----- |
+        /// | $(0, ∞)$ | $\R$  |
         ln,
         ln_impl,
         ln_rd,
@@ -478,7 +504,9 @@ impl Interval {
     impl_log!(
         /// Returns the base-10 logarithm of `self`.
         ///
-        /// Tightness: tightest
+        /// | Domain   | Range |
+        /// | -------- | ----- |
+        /// | $(0, ∞)$ | $\R$  |
         log10,
         log10_impl,
         log10_rd,
@@ -487,7 +515,9 @@ impl Interval {
     impl_log!(
         /// Returns the base-2 logarithm of `self`.
         ///
-        /// Tightness: tightest
+        /// | Domain   | Range |
+        /// | -------- | ----- |
+        /// | $(0, ∞)$ | $\R$  |
         log2,
         log2_impl,
         log2_rd,
@@ -496,7 +526,9 @@ impl Interval {
 
     /// Returns `self` raised to the power of `rhs`.
     ///
-    /// Tightness: tightest
+    /// | Domain                              | Range     |
+    /// | ----------------------------------- | --------- |
+    /// | $((0, ∞) × \R) ∪ (\set 0 × (0, ∞))$ | $\[0, ∞)$ |
     pub fn pow(self, rhs: Self) -> Self {
         self.pow_impl(rhs).0
     }
@@ -568,7 +600,15 @@ impl Interval {
 
     /// Returns `self` raised to the power of `rhs`.
     ///
-    /// Tightness: tightest
+    /// For a fixed $n ∈ \Z$, the domain and the range of the point function $\operatorname{pown}(x, n)$ are:
+    ///
+    /// |                | Domain        | Range         |
+    /// | -------------- | ------------- | ------------- |
+    /// | $n > 0$, odd   | $\R$          | $\R$          |
+    /// | $n > 0$, even  | $\R$          | $\[0, ∞)$     |
+    /// | $n = 0$        | $\R$          | $\set 1$      |
+    /// | $n < 0$, odd   | $\R ∖ \set 0$ | $\R ∖ \set 0$ |
+    /// | $n < 0$, even  | $\R ∖ \set 0$ | $(0, ∞)$      |
     pub fn pown(self, rhs: i32) -> Self {
         self.pown_impl(rhs).0
     }
@@ -630,7 +670,9 @@ impl Interval {
 
     /// Returns the sine of `self`.
     ///
-    /// Tightness: tightest
+    /// | Domain | Range       |
+    /// | ------ | ----------- |
+    /// | $\R$   | $\[-1, 1\]$ |
     pub fn sin(self) -> Self {
         if self.is_empty() {
             return self;
@@ -664,7 +706,9 @@ impl Interval {
     impl_mono_inc!(
         /// Returns the hyperbolic sine of `self`.
         ///
-        /// Tightness: tightest
+        /// | Domain | Range |
+        /// | ------ | ----- |
+        /// | $\R$   | $\R$  |
         sinh,
         sinh_rd,
         sinh_ru
@@ -672,7 +716,9 @@ impl Interval {
 
     /// Returns the tangent of `self`.
     ///
-    /// Tightness: tightest
+    /// | Domain                            | Range |
+    /// | --------------------------------- | ----- |
+    /// | $\R ∖ \set{(n + 1/2) π ∣ n ∈ \Z}$ | $\R$  |
     pub fn tan(self) -> Self {
         self.tan_impl().0
     }
@@ -703,7 +749,9 @@ impl Interval {
     impl_mono_inc!(
         /// Returns the hyperbolic tangent of `self`.
         ///
-        /// Tightness: tightest
+        /// | Domain | Range     |
+        /// | ------ | --------- |
+        /// | $\R$   | $(-1, 1)$ |
         tanh,
         tanh_rd,
         tanh_ru
@@ -712,14 +760,18 @@ impl Interval {
 
 macro_rules! impl_dec {
     ($f:ident) => {
-        #[doc = concat!("See [`Interval::", stringify!($f), "`].")]
+        #[doc = concat!("The decorated version of [`Interval::", stringify!($f), "`].")]
+        ///
+        /// A NaI is returned if `self` is NaI.
         pub fn $f(self) -> Self {
             Self::set_dec(self.x.$f(), self.d)
         }
     };
 
     ($f:ident, $f_impl:ident) => {
-        #[doc = concat!("See [`Interval::", stringify!($f), "`].")]
+        #[doc = concat!("The decorated version of [`Interval::", stringify!($f), "`].")]
+        ///
+        /// A NaI is returned if `self` is NaI.
         pub fn $f(self) -> Self {
             let (y, d) = self.x.$f_impl();
             Self::set_dec(y, self.d.min(d))
@@ -729,7 +781,9 @@ macro_rules! impl_dec {
 
 macro_rules! impl_dec2 {
     ($f:ident, $f_impl:ident) => {
-        #[doc = concat!("See [`Interval::", stringify!($f), "`].")]
+        #[doc = concat!("The decorated version of [`Interval::", stringify!($f), "`].")]
+        ///
+        /// A NaI is returned if `self` or `rhs` is NaI.
         pub fn $f(self, rhs: Self) -> Self {
             let (z, d) = self.x.$f_impl(rhs.x);
             Self::set_dec(z, self.d.min(rhs.d.min(d)))
@@ -755,7 +809,9 @@ impl DecInterval {
     impl_dec!(log2, log2_impl);
     impl_dec2!(pow, pow_impl);
 
-    /// See [`Interval::pown`].
+    /// The decorated version of [`Interval::pown`].
+    ///
+    /// A NaI is returned if `self` is NaI.
     pub fn pown(self, rhs: i32) -> Self {
         let (y, d) = self.x.pown_impl(rhs);
         Self::set_dec(y, self.d.min(d))
